from setuptools import setup, find_packages

setup(
    name='safexzutils',
    version='0.1.3',
    author='safeutils',
    author_email='back_man007@163.com',
    packages=["safexzutils"],
    license='LICENSE.txt',
    description='independent functions',
    long_description=open('README.md').read(),
    python_requires='>=3',
)
